##  Step 3. Visualize the Impact of Your Transformations and Compare
It is important to understand how your current architecture will be impacted by the envisioned Transformations and Impacts before implementing the change. You can achieve this by using Reports. Below are some examples to inspire your efforts:
  * You can make use of Landscape Reports to show which active Applications are affected by the transformations and how. You can cluster the Applications by Business Capabilities in scope, and apply the filters to narrow down the view to specific projects. You can show how Functional Fit and Technical Fit have improved compared to the current state by choosing them as Left and Right properties.
![Impact view in Reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743d2a47a441014a92db37b043523de_LowRes.png)
Impact view in Reports
  * Build Application Landscape Reports for as-is and the future-state landscape, then add them to the Dashboard to show the contrast and status of progress.
![Comparison of multiple scenarios](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274940267a441014979ae7b81251da49_LowRes.png)
Comparison of multiple scenarios
  * Before deciding on the best implementation option, compare various scenarios with different Transformations and Impacts defined. Make use of different Reports for comparison.
In the below example, a comparison is made for applications in Brazil and Canada regions in Finance Business Capability. The comparison reveals that Brazil has more business-critical applications with lower functional fit compared to Canada. Upon comparing priorities, it becomes clear that applications in Brazil are already flagged for earlier replacement. When an Initiative is applied to the timeline, it becomes evident how these applications are affected by that Initiative. This kind of comparison helps you choose which projects to focus on, helping you to narrow the scope of your efforts for quick wins.
![Comparison of multiple scenarios](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d52877a441014bc7df472bf949fc8_LowRes.gif)
Comparison of multiple scenarios


To learn more about using Reports, see [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD).
